#!/bin/bash

# Site backup
# Adapted from http://www.dockstreetmedia.com/2011/03/automatic-site-backups-using-cron-jobs-in-dreamhost/


# specific config variables (EDIT THESE)
#
# Space separated list of the names of folders 
# below your home directory, that you want to backup
DIRNAMES="topFolderA topFolderB topFolderC"
# host for your site's database(s)
DBHOST=mysql.example.com
# user name for this mysql server
DBUSER=myusername
# corresponding password (the same you gave 
# to the applications powering your site (like wordpress etc)
DBPASS=xxx
# Space separated list of the names of dbs 
# within DBHOST that you want to backup
DBNAMES="sitedb_one sitedb_two sitedb_three"



# other config variables(DO NOT EDIT THESE)
NOWDATE=$(date +"%y%m%d")
NOWDAY=$(date +"%d")
BACKUPDIR=backups
MYSQLDUMP="$(which mysqldump)"
LOGFILE=$HOME/$BACKUPDIR/log.txt

TARGETPATH=$HOME/$BACKUPDIR/$NOWDAY
LINK_TO_LATEST=$HOME/$BACKUPDIR/Latest

# check to see if target path exists – if so, delete the old one and create a new one, otherwise just create it
if [ -d $TARGETPATH ]
then
# print a message for the logfile / output email
echo "$NOWDATE - Removing previous backup $TARGETPATH" | tee -a $LOGFILE
rm -r $TARGETPATH
mkdir -p $TARGETPATH
else
mkdir -p $TARGETPATH
fi

for SITEDIR in $DIRNAMES
do

# create a GZIP of the directory inside the target path
tar -zcf $TARGETPATH/${SITEDIR}_$NOWDATE.tar.gz $HOME/$SITEDIR
# print a message for the logfile / output email
echo "$NOWDATE - $SITEDIR has been backed up" | tee -a $LOGFILE

done

for DBNAME in $DBNAMES
do
# dump the data into a SQL file inside the target path
$MYSQLDUMP -u $DBUSER -h $DBHOST -p$DBPASS $DBNAME | gzip > $TARGETPATH/${DBNAME}_$NOWDATE.sql.gz
# print a message for the logfile / output email
echo "$NOWDATE - $DBNAME has been backed up" | tee -a $LOGFILE
done

# Put a link to the latest backup
if [ -e $LINK_TO_LATEST ]
then
rm $LINK_TO_LATEST
fi

ln -s $TARGETPATH $LINK_TO_LATEST


